import bpy

def add_node_group_options(self, context):
    layout = self.layout
        
    if context.active_node and (context.active_node.bl_idname == 'GeometryNodeGroup' or context.active_node.bl_idname == 'ShaderNodeGroup' or context.active_node.bl_idname == 'CompositorNodeGroup'):
        layout.separator()
        layout.operator("node.set_default_values", text="Set Default Values", icon='SORT_ASC')
        layout.operator("node.reset_default_values", text="Reset to Default Values", icon='LOOP_BACK')
        

class SetDefaultValues(bpy.types.Operator):
    """Set the default values of the selected node group to the current values of its input sockets"""
    bl_idname = "node.set_default_values"
    bl_label = "Set Default Values"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        node_active = context.active_node
        node_tree = node_active.node_tree

        for item in node_tree.interface.items_tree:
            if item.item_type == 'SOCKET' and item.in_out == 'INPUT':
                try:
                    item.default_value = node_active.inputs[item.name].default_value
                except:
                    pass
            
        self.report({'INFO'}, "Default values set")
        return {'FINISHED'}

class ResetDefaultValues(bpy.types.Operator):
    """Reset the values of the input sockets of the selected node group to their default values"""
    bl_idname = "node.reset_default_values"
    bl_label = "Reset Default Values"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        node_active = context.active_node
        node_tree = node_active.node_tree

        for item in node_tree.interface.items_tree:
            if item.item_type == 'SOCKET' and item.in_out == 'INPUT':
                try:
                    node_active.inputs[item.name].default_value = item.default_value
                except:
                    pass

        return {'FINISHED'}

        
def register():
    bpy.utils.register_class(SetDefaultValues)
    bpy.utils.register_class(ResetDefaultValues)
    bpy.types.NODE_MT_context_menu.append(add_node_group_options)

def unregister():
    bpy.utils.unregister_class(SetDefaultValues)
    bpy.utils.unregister_class(ResetDefaultValues)
    bpy.types.NODE_MT_context_menu.remove(add_node_group_options)

if __name__ == "__main__":
    register()
